@@ -63,9 +63,9 @@ async def on_message(message: discord.Message):
 
     roles = bot_client.guilds[0].me.roles
     if any("Dev" in role.name for role in roles):
-        if platform.node().lower() == "secureerase.local":
+        if platform.node().lower() == "secureerase":
             return
-    elif platform.node().lower() != "secureerase.local":
+    elif platform.node().lower() != "secureerase":
         return
     prompt = message.content
     if bot_client.user.mentioned_in(message) or not message.guild:
@@ -73,14 +73,16 @@ async def on_message(message: discord.Message):
             prompt = prompt.replace(bot_client.user.mention, "").strip()
 
         engine = "text-davinci-003"
-        if prompt.split()[0].lower() == "reset":
-            bot_client.user_threads[message.author.id] = ""
-            prompt = " ".join(prompt.split()[1:]).strip()
-        if len(prompt.strip()) == 0:
-            return
+
         if prompt.split()[0].lower() == "code" and len(prompt.split()) > 2:
             engine = "code-davinci-002"
             prompt = " ".join(prompt.split()[1:]).strip()
+        if message.author.id not in bot_client.user_threads:
+            bot_client.user_threads[message.author.id] = ""
+        if message.reference:
+            bot_client.user_threads[message.author.id] += f"\n{prompt}"
+        else:
+            bot_client.user_threads[message.author.id] = prompt
 
         if prompt.split()[0].lower() == "image" and len(prompt.split()) > 2:
             image_engine = "image-alpha-001"
@@ -117,9 +119,6 @@ async def get_walle_image(message: discord.Message, prompt: str, engine: str):
 
 
 async def get_chatgpt_message(message: discord.Message, engine: str, prompt: str):
-    if message.author.id not in bot_client.user_threads:
-        bot_client.user_threads[message.author.id] = ""
-    bot_client.user_threads[message.author.id] += f"\n{prompt}"
     print(f"Sending message: {str(bot_client.user_threads[message.author.id]).strip()} to {engine}")
     try:
         response = await openai.Completion.acreate(
